package com.wzj.soopin.member.service;

import com.wzj.soopin.member.domain.vo.IMCallbackVO;

import java.util.Map;

public interface IMCallbackService {
    IMCallbackVO handleImFollow(Map<String, Object> params);

    IMCallbackVO handleImCancelFollow(Map<String, Object> params);
    IMCallbackVO handleImAddBlock(Map<String, Object> params);

    IMCallbackVO handleImCancelBlock(Map<String, Object> params);

    IMCallbackVO handleProfileCallbackPortraitSet(Map<String, Object> params);

}
